<h1 align="center">Olympia</h1>
<p align="center">Data structures and algorithms in Python 🐍</p>
<p align="center">
<a href="https://github.com/lukemiloszewski/olympia/actions/workflows/ci.yml/badge.svg" target="_blank">
    <img src="https://github.com/lukemiloszewski/olympia/actions/workflows/ci.yml/badge.svg" alt="Continuous Integration">
</a>
<a href="https://codecov.io/gh/lukemiloszewski/olympia" target="_blank">
    <img src="https://img.shields.io/codecov/c/github/lukemiloszewski/olympia?color=%2334D058" alt="Test Coverage">
</a>
<a href="https://pypi.org/project/olympia" target="_blank">
    <img src="https://img.shields.io/pypi/v/olympia?color=%2334D058&label=pypi%20package" alt="Package Version">
</a>
<a href="https://pypi.org/project/olympia" target="_blank">
    <img src="https://img.shields.io/pypi/pyversions/olympia.svg?color=%2334D058" alt="Supported Python Versions">
</a>
</p>

## Installation

```python
pip install olympia
```

## Usage

```python
from olympia import LinkedList

ll = LinkedList()
ll.add_last(1)
ll.add_last(2)
ll.add_last(3)
ll

1 -> 2 -> 3 -> None
```
